@@ -1,2 +1,5 @@
+""" Status
+"""
+
 ACTIVE = "Active"
 DELETED = "Deleted"
