@@ -5,32 +5,65 @@ OaiData model
 import operator
 from functools import reduce
 
-from django_mongoengine import fields, Document
-from mongoengine import errors as mongoengine_errors
-from mongoengine.queryset.visitor import Q
+from django.core.exceptions import ObjectDoesNotExist
+from django.db import models
+from django.db.models import Q
 
 from core_main_app.commons import exceptions
 from core_main_app.components.data.models import Data
 from core_main_app.components.template.models import Template
 
 
-class OaiData(Document):
+class OaiData(models.Model):
     """Represents a data for Oai-Pmh Provider"""
 
-    data = fields.ReferenceField(Data, blank=False)
-    oai_date_stamp = fields.DateTimeField(blank=False, default=None)
-    status = fields.StringField(blank=False)
-    template = fields.ReferenceField(Template, blank=False)
+    data = models.ForeignKey(
+        Data, blank=False, null=True, on_delete=models.SET_NULL
+    )
+    oai_date_stamp = models.DateTimeField(blank=False, null=True, default=None)
+    status = models.CharField(blank=False, max_length=200)
+    template = models.ForeignKey(
+        Template, blank=False, null=True, on_delete=models.SET_NULL
+    )
 
-    @property
-    def data_id(self):
-        """Get data id even if the reference is broken (Deleted Data).
+    class Meta:
+        """Meta"""
+
+        verbose_name = "Oai data"
+        verbose_name_plural = "Oai data"
+
+    @staticmethod
+    def _filter_by_date(from_date, until_date):
+        """Create Q query to filter between two dates
+
+        Args:
+            from_date:
+            until_date:
 
         Returns:
-            ObjectId: Data id.
-
+            list - The query to be used to filter item between these dates
         """
-        return self._data["data"].id
+        qlist = []
+
+        if from_date:
+            qlist.append(Q(oai_date_stamp__gte=from_date))
+
+        if until_date:
+            qlist.append(Q(oai_date_stamp__lte=until_date))
+
+        return qlist
+
+    @staticmethod
+    def _filter_public_data():
+        """Create Q query to output public data only
+
+        Returns:
+             list - Filters to only return public data
+        """
+        return [
+            Q(data__workspace__isnull=False),
+            Q(data__workspace__is_public=True),
+        ]
 
     @staticmethod
     def get_by_id(oai_data_id):
@@ -49,8 +82,8 @@ class OaiData(Document):
         """
         try:
             return OaiData.objects.get(pk=str(oai_data_id))
-        except mongoengine_errors.DoesNotExist as e:
-            raise exceptions.DoesNotExist(str(e))
+        except ObjectDoesNotExist as exception:
+            raise exceptions.DoesNotExist(str(exception))
         except Exception as ex:
             raise exceptions.ModelError(str(ex))
 
@@ -71,11 +104,21 @@ class OaiData(Document):
         """
         try:
             return OaiData.objects.get(data=data)
-        except mongoengine_errors.DoesNotExist as e:
-            raise exceptions.DoesNotExist(str(e))
+        except ObjectDoesNotExist as exception:
+            raise exceptions.DoesNotExist(str(exception))
         except Exception as ex:
             raise exceptions.ModelError(str(ex))
 
+    @staticmethod
+    def get_all():
+        """Return all OaiData.
+
+        Returns:
+            List of OaiData.
+
+        """
+        return OaiData.objects.all()
+
     @staticmethod
     def get_all_by_data_list_and_timeframe(data_list, from_date, until_date):
         """Get all OaiData from a specific data list.
@@ -88,26 +131,14 @@ class OaiData(Document):
         Returns:
             List of OaiData instance.
         """
-        q_list = [Q(data__in=data_list)]
-        if from_date:
-            q_list.append(Q(oai_date_stamp__gte=from_date))
-        if until_date:
-            q_list.append(Q(oai_date_stamp__lte=until_date))
+        q_list = [Q(data__in=data_list)] + OaiData._filter_by_date(
+            from_date, until_date
+        )
 
-        return OaiData.objects(reduce(operator.and_, q_list)).all()
+        return OaiData.objects.filter(reduce(operator.and_, q_list)).all()
 
     @staticmethod
-    def get_all():
-        """Return all OaiData.
-
-        Returns:
-            List of OaiData.
-
-        """
-        return OaiData.objects().all()
-
-    @staticmethod
-    def get_all_by_template(template, from_date, until_date):
+    def get_all_by_template_and_timeframe(template, from_date, until_date):
         """Get all OaiData used by a template.
 
         Args:
@@ -119,13 +150,32 @@ class OaiData(Document):
             List of OaiData.
 
         """
-        q_list = [Q(template=template)]
-        if from_date:
-            q_list.append(Q(oai_date_stamp__gte=from_date))
-        if until_date:
-            q_list.append(Q(oai_date_stamp__lte=until_date))
+        q_list = [Q(template=template)] + OaiData._filter_by_date(
+            from_date, until_date
+        )
 
-        return OaiData.objects(reduce(operator.and_, q_list)).all()
+        return OaiData.objects.filter(reduce(operator.and_, q_list)).all()
+
+    @staticmethod
+    def get_all_by_template_list_and_timeframe(
+        template_list, from_date, until_date
+    ):
+        """Get all OaiData used by a list of templates.
+
+        Args:
+            template_list: List of templates.
+            from_date:
+            until_date:
+
+        Returns:
+            List of OaiData.
+
+        """
+        q_list = [Q(template__in=template_list)] + OaiData._filter_by_date(
+            from_date, until_date
+        )
+
+        return OaiData.objects.filter(reduce(operator.and_, q_list)).all()
 
     @staticmethod
     def get_all_by_status(status):
@@ -137,7 +187,7 @@ class OaiData(Document):
             List of OaiData.
 
         """
-        return OaiData.objects(status=status).all()
+        return OaiData.objects.filter(status=status).all()
 
     @staticmethod
     def get_earliest_data_date():
@@ -147,8 +197,18 @@ class OaiData(Document):
 
         """
         try:
-            earliest_record = OaiData.objects().order_by("oai_date_stamp").first()
+            earliest_record = OaiData.objects.order_by(
+                "oai_date_stamp"
+            ).first()
 
             return earliest_record.oai_date_stamp
         except Exception as ex:
             raise exceptions.ModelError(str(ex))
+
+    def __str__(self):
+        """Return OAIData object as string
+
+        Returns:
+
+        """
+        return f"{self.data.title if self.data else 'DELETED'} ({self.pk})"
