@@ -6,13 +6,12 @@ from rest_framework.exceptions import ValidationError
 from rest_framework.response import Response
 from rest_framework.views import APIView
 
-
+import core_oaipmh_provider_app.components.oai_provider_set.api as oai_provider_set_api
 from core_main_app.commons import exceptions
 from core_main_app.utils.decorators import api_staff_member_required
 from core_oaipmh_common_app.commons import exceptions as exceptions_oai
 from core_oaipmh_common_app.commons.messages import OaiPmhMessage
 from core_oaipmh_provider_app.rest import serializers
-import core_oaipmh_provider_app.components.oai_provider_set.api as oai_provider_set_api
 
 
 class SetsList(APIView):
@@ -42,7 +41,9 @@ class SetsList(APIView):
             return Response(serializer.data, status=status.HTTP_200_OK)
         except Exception as exception:
             content = OaiPmhMessage.get_message_labelled(str(exception))
-            return Response(content, status=status.HTTP_500_INTERNAL_SERVER_ERROR)
+            return Response(
+                content, status=status.HTTP_500_INTERNAL_SERVER_ERROR
+            )
 
     @method_decorator(api_staff_member_required())
     def post(self, request):
@@ -76,20 +77,26 @@ class SetsList(APIView):
                 data=request.data, context={"request": request}
             )
             # Validate data
-            serializer.is_valid(True)
+            serializer.is_valid(raise_exception=True)
             # Save data
             serializer.save()
-            content = OaiPmhMessage.get_message_labelled("Set added with success.")
+            content = OaiPmhMessage.get_message_labelled(
+                "Set added with success."
+            )
 
             return Response(content, status=status.HTTP_201_CREATED)
         except ValidationError as validation_exception:
-            content = OaiPmhMessage.get_message_labelled(validation_exception.detail)
+            content = OaiPmhMessage.get_message_labelled(
+                validation_exception.detail
+            )
             return Response(content, status=status.HTTP_400_BAD_REQUEST)
         except exceptions_oai.OAIAPIException as exception:
             return exception.response()
         except Exception as exception:
             content = OaiPmhMessage.get_message_labelled(str(exception))
-            return Response(content, status=status.HTTP_500_INTERNAL_SERVER_ERROR)
+            return Response(
+                content, status=status.HTTP_500_INTERNAL_SERVER_ERROR
+            )
 
 
 class SetDetail(APIView):
@@ -129,7 +136,9 @@ class SetDetail(APIView):
             return exception.response()
         except Exception as exception:
             content = OaiPmhMessage.get_message_labelled(str(exception))
-            return Response(content, status=status.HTTP_500_INTERNAL_SERVER_ERROR)
+            return Response(
+                content, status=status.HTTP_500_INTERNAL_SERVER_ERROR
+            )
 
     @method_decorator(api_staff_member_required())
     def delete(self, request, set_id):
@@ -163,7 +172,9 @@ class SetDetail(APIView):
             return exception.response()
         except Exception as exception:
             content = OaiPmhMessage.get_message_labelled(str(exception))
-            return Response(content, status=status.HTTP_500_INTERNAL_SERVER_ERROR)
+            return Response(
+                content, status=status.HTTP_500_INTERNAL_SERVER_ERROR
+            )
 
     @method_decorator(api_staff_member_required())
     def patch(self, request, set_id):
@@ -199,14 +210,18 @@ class SetDetail(APIView):
                 instance=set_, data=request.data, context={"request": request}
             )
             # Validate data
-            serializer.is_valid(True)
+            serializer.is_valid(raise_exception=True)
             # Save data
             serializer.save()
-            content = OaiPmhMessage.get_message_labelled("Set updated with success.")
+            content = OaiPmhMessage.get_message_labelled(
+                "Set updated with success."
+            )
 
             return Response(content, status=status.HTTP_200_OK)
         except ValidationError as validation_exception:
-            content = OaiPmhMessage.get_message_labelled(validation_exception.detail)
+            content = OaiPmhMessage.get_message_labelled(
+                validation_exception.detail
+            )
             return Response(content, status=status.HTTP_400_BAD_REQUEST)
         except exceptions.DoesNotExist:
             content = OaiPmhMessage.get_message_labelled(
@@ -217,4 +232,6 @@ class SetDetail(APIView):
             return exception.response()
         except Exception as exception:
             content = OaiPmhMessage.get_message_labelled(str(exception))
-            return Response(content, status=status.HTTP_500_INTERNAL_SERVER_ERROR)
+            return Response(
+                content, status=status.HTTP_500_INTERNAL_SERVER_ERROR
+            )
