@@ -22,13 +22,15 @@ CUSTOM_NAME = getattr(settings, "CUSTOM_NAME", "")
 RESULTS_PER_PAGE = getattr(settings, "RESULTS_PER_PAGE", 10)
 
 # OAI_PMH parameters
-OAI_ADMINS = (("Administrator", "admin@example.com"),)
+OAI_ADMINS = getattr(settings, "OAI_ADMINS", None)
 OAI_HOST_URI = SERVER_URI
 OAI_NAME = CUSTOM_NAME + " OAI-PMH Server"
 OAI_DELIMITER = ":"
 OAI_DESCRIPTION = "OAI-PMH " + CUSTOM_NAME
 OAI_GRANULARITY = "YYYY-MM-DDThh:mm:ssZ"  # the finest harvesting granularity supported by the repository
-OAI_PROTOCOL_VERSION = "2.0"  # the version of the OAI-PMH supported by the repository
+OAI_PROTOCOL_VERSION = (
+    "2.0"  # the version of the OAI-PMH supported by the repository
+)
 OAI_SCHEME = "oai"
 OAI_REPO_IDENTIFIER = "server-x"
 OAI_SAMPLE_IDENTIFIER = (
