@@ -3,14 +3,14 @@ Check OAI-PMH request utils.
 
 """
 import re
-from datetime import datetime
 
 import core_oaipmh_provider_app.commons.exceptions as oai_provider_exceptions
+from core_main_app.utils.datetime import datetime_now
+from core_oaipmh_common_app.utils import UTCdatetime
+from core_oaipmh_provider_app import settings
 from core_oaipmh_provider_app.components.oai_request_page import (
     api as oai_request_page_api,
 )
-from core_oaipmh_common_app.utils import UTCdatetime
-from core_oaipmh_provider_app import settings
 
 
 def check_bad_argument(oai_verb, data):
@@ -89,7 +89,8 @@ def check_illegal_and_required(legal, required, data):
     if len(illegal) > 0:
         for arg in illegal:
             error = (
-                'Arguments ("%s") was passed that was not valid for ' "this verb" % arg
+                'Arguments ("%s") was passed that was not valid for '
+                "this verb" % arg
             )
             errors.append(oai_provider_exceptions.BadArgument(error))
     # Check if a parameter is missing for the request
@@ -117,10 +118,10 @@ def check_identifier(identifier):
 
     """
     # Check if the identifier pattern is OK.
-    p = re.compile(
+    pattern = re.compile(
         "%s:%s:id/(.*)" % (settings.OAI_SCHEME, settings.OAI_REPO_IDENTIFIER)
     )
-    id_matches = p.search(identifier)
+    id_matches = pattern.search(identifier)
     if id_matches:
         # If yes, we retrieve the record ID
         record_id = id_matches.group(1)
@@ -144,7 +145,7 @@ def check_from(date):
     """
     try:
         return _check_dates(date)
-    except:
+    except Exception:
         error = 'Illegal date/time for "from" (%s)' % date
         raise oai_provider_exceptions.BadArgument(error)
 
@@ -163,7 +164,7 @@ def check_until(date):
     """
     try:
         return _check_dates(date)
-    except:
+    except Exception:
         error = 'Illegal date/time for "until" (%s)' % date
         raise oai_provider_exceptions.BadArgument(error)
 
@@ -182,8 +183,8 @@ def _check_dates(date):
     """
     try:
         return UTCdatetime.utc_datetime_iso8601_to_datetime(date)
-    except Exception as e:
-        raise e
+    except Exception as exception:
+        raise exception
 
 
 def check_resumption_token(resumption_token):
@@ -205,7 +206,7 @@ def check_resumption_token(resumption_token):
         # Check if the resumption token is not expired
         if UTCdatetime.datetime_to_utc_datetime_iso8601(
             oai_request_page_object.expiration_date
-        ) < UTCdatetime.datetime_to_utc_datetime_iso8601(datetime.now()):
+        ) < UTCdatetime.datetime_to_utc_datetime_iso8601(datetime_now()):
             raise Exception("Token expired")
 
         return oai_request_page_object
