@@ -1,6 +1,9 @@
+""" User views
+"""
+
 import logging
 import re
-from datetime import datetime, timedelta
+from datetime import datetime
 from io import StringIO
 
 from django.core.paginator import Paginator
@@ -16,9 +19,12 @@ import core_oaipmh_provider_app.components.oai_xsl_template.api as oai_xsl_templ
 from core_main_app.commons import exceptions as exceptions
 from core_main_app.components.data import api as data_api
 from core_main_app.components.template import api as template_api
+from core_main_app.components.template_version_manager import (
+    api as template_version_manager_api,
+)
 from core_main_app.components.version_manager import api as version_manager_api
-from core_main_app.components.workspace import api as workspace_api
 from core_main_app.system import api as system_api
+from core_main_app.utils.datetime import datetime_now, datetime_timedelta
 from core_main_app.utils.xsd_flattener.xsd_flattener_database_url import (
     XSDFlattenerDatabaseOrURL,
 )
@@ -35,8 +41,12 @@ from core_oaipmh_provider_app.components.oai_provider_set import (
 from core_oaipmh_provider_app.components.oai_request_page import (
     api as oai_request_page_api,
 )
-from core_oaipmh_provider_app.components.oai_request_page.models import OaiRequestPage
-from core_oaipmh_provider_app.components.oai_settings import api as oai_settings_api
+from core_oaipmh_provider_app.components.oai_request_page.models import (
+    OaiRequestPage,
+)
+from core_oaipmh_provider_app.components.oai_settings import (
+    api as oai_settings_api,
+)
 from core_oaipmh_provider_app.settings import (
     RESULTS_PER_PAGE,
     CAN_ANONYMOUS_ACCESS_PUBLIC_DOCUMENT,
@@ -47,10 +57,12 @@ logger = logging.getLogger(__name__)
 
 
 class OAIProviderView(TemplateView):
+    """OAI Provider View"""
+
     content_type = "text/xml"
 
     def __init__(self, **kwargs):
-        super(OAIProviderView, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         self.request = None
         self.oai_verb = None
         self.metadata_prefix = None
@@ -61,6 +73,15 @@ class OAIProviderView(TemplateView):
         self.resumption_token = None
 
     def render_to_response(self, context, **response_kwargs):
+        """render_to_response
+
+        Args:
+            context:
+            response_kwargs:
+
+        Returns:
+
+        """
         # All OAI responses should be XML
         if "content_type" not in response_kwargs:
             response_kwargs["content_type"] = self.content_type
@@ -68,7 +89,9 @@ class OAIProviderView(TemplateView):
         # Add common context data needed for all responses
         context.update(
             {
-                "now": UTCdatetime.datetime_to_utc_datetime_iso8601(datetime.now()),
+                "now": UTCdatetime.datetime_to_utc_datetime_iso8601(
+                    datetime_now()
+                ),
                 "verb": self.oai_verb,
                 "identifier": self.identifier,
                 "metadataPrefix": self.metadata_prefix,
@@ -83,9 +106,25 @@ class OAIProviderView(TemplateView):
         return super().render_to_response(context, **response_kwargs)
 
     def error(self, error):
+        """error
+
+        Args:
+            error:
+
+        Returns:
+
+        """
         return self.errors([error])
 
     def errors(self, errors):
+        """errors
+
+        Args:
+            errors:
+
+        Returns:
+
+        """
         self.template_name = "core_oaipmh_provider_app/user/xml/error.html"
         return self.render_to_response(
             {
@@ -94,6 +133,14 @@ class OAIProviderView(TemplateView):
         )
 
     def get(self, request, *args, **kwargs):
+        """get
+
+        Args:
+            request:
+
+        Returns:
+
+        """
         try:
             # Check if the server is enabled for providing information.
             information = oai_settings_api.get()
@@ -116,24 +163,24 @@ class OAIProviderView(TemplateView):
             # Verb processing.
             if self.oai_verb == "Identify":
                 return self.identify()
-            elif self.oai_verb == "GetRecord":
+            if self.oai_verb == "GetRecord":
                 return self.get_record()
-            elif self.oai_verb == "ListSets":
+            if self.oai_verb == "ListSets":
                 return self.list_sets()
-            elif self.oai_verb == "ListIdentifiers":
+            if self.oai_verb == "ListIdentifiers":
                 return self.list_identifiers()
-            elif self.oai_verb == "ListMetadataFormats":
+            if self.oai_verb == "ListMetadataFormats":
                 return self.list_metadata_formats()
-            elif self.oai_verb == "ListRecords":
+            if self.oai_verb == "ListRecords":
                 return self.list_records()
 
-        except oai_provider_exceptions.OAIExceptions as e:
-            return self.errors(e.errors)
-        except oai_provider_exceptions.OAIException as e:
-            return self.error(e)
-        except Exception as e:
+        except oai_provider_exceptions.OAIExceptions as exception:
+            return self.errors(exception.errors)
+        except oai_provider_exceptions.OAIException as exception:
+            return self.error(exception)
+        except Exception as exception:
             return HttpResponse(
-                {"content": escape(str(e))},
+                {"content": escape(str(exception))},
                 status=status.HTTP_500_INTERNAL_SERVER_ERROR,
             )
 
@@ -153,7 +200,7 @@ class OAIProviderView(TemplateView):
         identify_data = {
             "name": information.repository_name,
             "protocol_version": settings.OAI_PROTOCOL_VERSION,
-            "admins": (email for name, email in settings.OAI_ADMINS),
+            "admins": settings.OAI_ADMINS,
             "earliest_date": self._get_earliest_date(),
             "deleted": settings.OAI_DELETED_RECORD,
             "granularity": settings.OAI_GRANULARITY,
@@ -174,26 +221,26 @@ class OAIProviderView(TemplateView):
         self.template_name = "core_oaipmh_provider_app/user/xml/list_sets.html"
         items = []
         try:
-            sets = oai_provider_set_api.get_all("set_spec")
+            sets = oai_provider_set_api.get_all(["set_spec"])
             if len(sets) == 0:
                 raise oai_provider_exceptions.NoSetHierarchy
-            else:
-                for set_ in sets:
-                    item_info = {
-                        "setSpec": set_.set_spec,
-                        "setName": set_.set_name,
-                        "description": set_.description,
-                    }
-                    items.append(item_info)
+
+            for set_ in sets:
+                item_info = {
+                    "setSpec": set_.set_spec,
+                    "setName": set_.set_name,
+                    "description": set_.description,
+                }
+                items.append(item_info)
 
             return self.render_to_response({"items": items})
-        except oai_provider_exceptions.OAIExceptions as e:
-            return self.errors(e.errors)
-        except oai_provider_exceptions.OAIException as e:
-            return self.error(e)
-        except Exception as e:
+        except oai_provider_exceptions.OAIExceptions as exception:
+            return self.errors(exception.errors)
+        except oai_provider_exceptions.OAIException as exception:
+            return self.error(exception)
+        except Exception as exception:
             return HttpResponse(
-                {"content": escape(str(e))},
+                {"content": escape(str(exception))},
                 status=status.HTTP_500_INTERNAL_SERVER_ERROR,
             )
 
@@ -228,36 +275,40 @@ class OAIProviderView(TemplateView):
                         xslt_metadata_formats
                     )
                 except Exception:
-                    raise oai_provider_exceptions.IdDoesNotExist(self.identifier)
+                    raise oai_provider_exceptions.IdDoesNotExist(
+                        self.identifier
+                    )
             else:
                 # No identifier provided. We return all metadata formats available
                 if CAN_ANONYMOUS_ACCESS_PUBLIC_DOCUMENT:
-                    metadata_formats = oai_provider_metadata_format_api.get_all()
+                    metadata_formats = (
+                        oai_provider_metadata_format_api.get_all()
+                    )
                 else:
                     metadata_formats = []
 
             if len(metadata_formats) == 0:
                 raise oai_provider_exceptions.NoMetadataFormat
-            else:
-                host_uri = self.request.build_absolute_uri("/")
-                for metadata_format in metadata_formats:
-                    item_info = {
-                        "metadataNamespace": metadata_format.metadata_namespace,
-                        "metadataPrefix": metadata_format.metadata_prefix,
-                        "schema": oai_provider_metadata_format_api.get_metadata_format_schema_url(
-                            metadata_format, host_uri
-                        ),
-                    }
-                    items.append(item_info)
+
+            host_uri = self.request.build_absolute_uri("/")
+            for metadata_format in metadata_formats:
+                item_info = {
+                    "metadataNamespace": metadata_format.metadata_namespace,
+                    "metadataPrefix": metadata_format.metadata_prefix,
+                    "schema": oai_provider_metadata_format_api.get_metadata_format_schema_url(
+                        metadata_format, host_uri
+                    ),
+                }
+                items.append(item_info)
 
             return self.render_to_response({"items": items})
-        except oai_provider_exceptions.OAIExceptions as e:
-            return self.errors(e.errors)
-        except oai_provider_exceptions.OAIException as e:
-            return self.error(e)
-        except Exception as e:
+        except oai_provider_exceptions.OAIExceptions as exception:
+            return self.errors(exception.errors)
+        except oai_provider_exceptions.OAIException as exception:
+            return self.error(exception)
+        except Exception as exception:
             return HttpResponse(
-                {"content": escape(str(e))},
+                {"content": escape(str(exception))},
                 status=status.HTTP_500_INTERNAL_SERVER_ERROR,
             )
 
@@ -267,7 +318,9 @@ class OAIProviderView(TemplateView):
             XML type response.
 
         """
-        self.template_name = "core_oaipmh_provider_app/user/xml/list_identifiers.html"
+        self.template_name = (
+            "core_oaipmh_provider_app/user/xml/list_identifiers.html"
+        )
         return self._treatment_list_items()
 
     def list_records(self):
@@ -276,7 +329,9 @@ class OAIProviderView(TemplateView):
            XML type response.
 
         """
-        self.template_name = "core_oaipmh_provider_app/user/xml/list_records.html"
+        self.template_name = (
+            "core_oaipmh_provider_app/user/xml/list_records.html"
+        )
         return self._treatment_list_items(include_metadata=True)
 
     def _treatment_list_items(self, include_metadata=False):
@@ -337,7 +392,9 @@ class OAIProviderView(TemplateView):
                 )
                 use_raw = False
 
-            templates_id_from_set = self._get_templates_id_by_set_spec(self.set)
+            templates_id_from_set = self._get_templates_id_by_set_spec(
+                self.set
+            )
             set(template_id_list).intersection(templates_id_from_set)
 
             (items, resumption_token) = self._get_items(
@@ -355,13 +412,13 @@ class OAIProviderView(TemplateView):
             return self.render_to_response(
                 {"items": items, "resumption_token": resumption_token}
             )
-        except oai_provider_exceptions.OAIExceptions as e:
-            return self.errors(e.errors)
-        except oai_provider_exceptions.OAIException as e:
-            return self.error(e)
-        except Exception as e:
+        except oai_provider_exceptions.OAIExceptions as exception:
+            return self.errors(exception.errors)
+        except oai_provider_exceptions.OAIException as exception:
+            return self.error(exception)
+        except Exception as exception:
             return HttpResponse(
-                {"content": escape(str(e))},
+                {"content": escape(str(exception))},
                 status=status.HTTP_500_INTERNAL_SERVER_ERROR,
             )
 
@@ -381,22 +438,20 @@ class OAIProviderView(TemplateView):
         output_resumption_token = None
 
         try:
-            # FIXME filtering public data is needed since all data has
-            # a OAI data associated with it
-            public_workspace_list = workspace_api.get_all_public_workspaces()
-            data_list = system_api.get_all_data_in_workspaces_for_templates(
-                public_workspace_list, template_id_list
-            )
-            oai_data = oai_data_api.get_all_by_data_list(
-                data_list, from_date=from_date, until_date=until_date
-            )
+            template_list = [
+                system_api.get_template_by_id(template_id)
+                for template_id in template_id_list
+            ]
+            oai_data = oai_data_api.get_all_by_template_list(
+                template_list, from_date=from_date, until_date=until_date
+            ).order_by("pk")
 
             oai_data_paginator = Paginator(oai_data, RESULTS_PER_PAGE)
 
             # If there are more pages to display
             if oai_data_paginator.num_pages > page_nb:
                 exp_date = UTCdatetime.datetime_to_utc_datetime_iso8601(
-                    datetime.now() + timedelta(days=7)
+                    datetime_now() + datetime_timedelta(days=7)
                 )
 
                 oai_request_page_object = oai_request_page_api.upsert(
@@ -428,7 +483,7 @@ class OAIProviderView(TemplateView):
                 identifier = "%s:%s:id/%s" % (
                     settings.OAI_SCHEME,
                     settings.OAI_REPO_IDENTIFIER,
-                    str(elt.data_id),
+                    str(elt.id),
                 )
                 item_info = {
                     "identifier": identifier,
@@ -436,7 +491,7 @@ class OAIProviderView(TemplateView):
                         elt.oai_date_stamp
                     ),
                     "sets": oai_provider_set_api.get_all_by_template_ids(
-                        [elt.data.template], request=request
+                        [elt.template.pk], request=request
                     ),
                     "deleted": elt.status == oai_status.DELETED,
                 }
@@ -451,13 +506,15 @@ class OAIProviderView(TemplateView):
                             elt.data.template, metadata_format
                         ).xslt
 
-                        xml = xsl_transformation_api.xsl_transform(xml, xslt.name)
+                        xml = xsl_transformation_api.xsl_transform(
+                            xml, xslt.name
+                        )
 
                     item_info.update({"xml": xml})
 
                 items.append(item_info)
-        except Exception as e:
-            logger.warning("_get_items threw an exception: {0}".format(str(e)))
+        except Exception as exception:
+            logger.warning("_get_items threw an exception: %s", str(exception))
 
         if len(items) == 0:  # No records retrieved
             raise oai_provider_exceptions.NoRecordsMatch
@@ -471,7 +528,9 @@ class OAIProviderView(TemplateView):
 
         """
         try:
-            self.template_name = "core_oaipmh_provider_app/user/xml/get_record.html"
+            self.template_name = (
+                "core_oaipmh_provider_app/user/xml/get_record.html"
+            )
             # Check if the identifier pattern is OK.
             record_id = request_checker.check_identifier(self.identifier)
             try:
@@ -491,13 +550,17 @@ class OAIProviderView(TemplateView):
                     and oai_data.template == metadata_format.template
                 )
                 if oai_data.status != oai_status.DELETED:
-                    xml = re.sub(r"<\?xml[^?]+\?>", "", oai_data.data.xml_content)
+                    xml = re.sub(
+                        r"<\?xml[^?]+\?>", "", oai_data.data.xml_content
+                    )
 
                     if not use_raw:
                         xslt = oai_xsl_template_api.get_by_template_id_and_metadata_format_id(
                             oai_data.template.id, metadata_format.id
                         ).xslt
-                        xml = xsl_transformation_api.xsl_transform(xml, xslt.name)
+                        xml = xsl_transformation_api.xsl_transform(
+                            xml, xslt.name
+                        )
                 else:
                     xml = None
             except Exception:
@@ -518,13 +581,13 @@ class OAIProviderView(TemplateView):
             }
 
             return self.render_to_response(record_info)
-        except oai_provider_exceptions.OAIExceptions as e:
-            return self.errors(e.errors)
-        except oai_provider_exceptions.OAIException as e:
-            return self.error(e)
-        except Exception as e:
+        except oai_provider_exceptions.OAIExceptions as exception:
+            return self.errors(exception.errors)
+        except oai_provider_exceptions.OAIException as exception:
+            return self.error(exception)
+        except Exception as exception:
             return HttpResponse(
-                {"content": escape(str(e))},
+                {"content": escape(str(exception))},
                 status=status.HTTP_500_INTERNAL_SERVER_ERROR,
             )
 
@@ -541,14 +604,18 @@ class OAIProviderView(TemplateView):
     def _get_templates_id_by_metadata_prefix(metadata_prefix):
         try:
             templates_id = []
-            metadata_format = oai_provider_metadata_format_api.get_by_metadata_prefix(
-                metadata_prefix
+            metadata_format = (
+                oai_provider_metadata_format_api.get_by_metadata_prefix(
+                    metadata_prefix
+                )
             )
             if metadata_format.is_template:
                 templates_id.append(str(metadata_format.template.id))
             return templates_id
         except Exception:
-            raise oai_provider_exceptions.CannotDisseminateFormat(metadata_prefix)
+            raise oai_provider_exceptions.CannotDisseminateFormat(
+                metadata_prefix
+            )
 
     @staticmethod
     def _get_templates_id_by_set_spec(set_spec):
@@ -582,12 +649,10 @@ def get_xsd(request, title, version_number):
 
     """
     try:
-        template_version = (
-            version_manager_api.get_active_global_version_manager_by_title(
-                title, request=request
-            )
+        template_version = template_version_manager_api.get_active_global_version_manager_by_title(
+            title, request=request
         )
-        template = template_api.get(
+        template = template_api.get_by_id(
             version_manager_api.get_version_by_number(
                 template_version, int(version_number), request=request
             ),
@@ -599,8 +664,8 @@ def get_xsd(request, title, version_number):
         file_obj = StringIO(content_encoded)
 
         return HttpResponse(file_obj, content_type="text/xml")
-    except Exception as e:
+    except Exception as exception:
         return HttpResponseBadRequest(
             "Impossible to retrieve the schema with the given name and "
-            "version: %s" % escape(str(e))
+            "version: %s" % escape(str(exception))
         )
