@@ -3,13 +3,12 @@
 
 from random import randint
 from unittest.case import TestCase
-
 from unittest.mock import Mock, patch
 
+import core_oaipmh_provider_app.components.oai_provider_metadata_format.api as provider_metadata_format_api
 from core_main_app.commons import exceptions
 from core_main_app.utils.tests_tools.MockUser import create_mock_user
 from core_main_app.utils.tests_tools.RequestMock import create_mock_request
-import core_oaipmh_provider_app.components.oai_provider_metadata_format.api as provider_metadata_format_api
 from core_oaipmh_provider_app.components.oai_provider_metadata_format.models import (
     OaiProviderMetadataFormat,
 )
@@ -20,10 +19,14 @@ class TestOaiProviderMetadataFormatUpsert(TestCase):
 
     def setUp(self):
         """setUp"""
-        self.mock_oai_provider_metadata_format = _create_oai_provider_metadata_format()
+        self.mock_oai_provider_metadata_format = (
+            _create_oai_provider_metadata_format()
+        )
 
     @patch.object(OaiProviderMetadataFormat, "save")
-    def test_oai_provider_metadata_format_upsert_returns_object(self, mock_save):
+    def test_oai_provider_metadata_format_upsert_returns_object(
+        self, mock_save
+    ):
         """test_oai_provider_metadata_format_upsert_returns_object"""
 
         # Arrange
@@ -50,7 +53,9 @@ class TestOaiProviderMetadataFormatUpsert(TestCase):
 
         # Act # Assert
         with self.assertRaises(Exception):
-            provider_metadata_format_api.upsert(self.mock_oai_provider_metadata_format)
+            provider_metadata_format_api.upsert(
+                self.mock_oai_provider_metadata_format
+            )
 
 
 class TestOaiProviderMetadataFormatGetById(TestCase):
@@ -61,7 +66,9 @@ class TestOaiProviderMetadataFormatGetById(TestCase):
         """test_get_by_id_return_object"""
 
         # Arrange
-        mock_oai_provider_metadata_format = _create_mock_oai_provider_metadata_format()
+        mock_oai_provider_metadata_format = (
+            _create_mock_oai_provider_metadata_format()
+        )
         mock_oai_provider_metadata_format.id = randint(1, 100)
 
         mock_get_by_id.return_value = mock_oai_provider_metadata_format
@@ -73,7 +80,9 @@ class TestOaiProviderMetadataFormatGetById(TestCase):
         self.assertIsInstance(result, OaiProviderMetadataFormat)
 
     @patch.object(OaiProviderMetadataFormat, "get_by_id")
-    def test_get_by_id_raises_exception_if_object_does_not_exist(self, mock_get_by_id):
+    def test_get_by_id_raises_exception_if_object_does_not_exist(
+        self, mock_get_by_id
+    ):
         """test_get_by_id_raises_exception_if_object_does_not_exist"""
 
         # Arrange
@@ -86,7 +95,9 @@ class TestOaiProviderMetadataFormatGetById(TestCase):
             provider_metadata_format_api.get_by_id(mock_absent_id)
 
     @patch.object(OaiProviderMetadataFormat, "get_by_id")
-    def test_get_by_id_raises_exception_if_internal_error(self, mock_get_by_id):
+    def test_get_by_id_raises_exception_if_internal_error(
+        self, mock_get_by_id
+    ):
         """test_get_by_id_raises_exception_if_internal_error"""
 
         # Arrange
@@ -107,7 +118,9 @@ class TestOaiProviderMetadataFormatGetByMetadataPrefix(TestCase):
         """test_get_by_metadata_prefix_return_object"""
 
         # Arrange
-        mock_oai_provider_metadata_format = _create_mock_oai_provider_metadata_format()
+        mock_oai_provider_metadata_format = (
+            _create_mock_oai_provider_metadata_format()
+        )
 
         mock_get.return_value = mock_oai_provider_metadata_format
 
@@ -137,7 +150,9 @@ class TestOaiProviderMetadataFormatGetByMetadataPrefix(TestCase):
             )
 
     @patch.object(OaiProviderMetadataFormat, "get_by_metadata_prefix")
-    def test_get_by_metadata_prefix_raises_exception_if_internal_error(self, mock_get):
+    def test_get_by_metadata_prefix_raises_exception_if_internal_error(
+        self, mock_get
+    ):
         """test_get_by_metadata_prefix_raises_exception_if_internal_error"""
 
         # Arrange
@@ -156,7 +171,9 @@ class TestOaiProviderMetadataFormatGetAll(TestCase):
     """Test Oai Provider Metadata Format Get All"""
 
     @patch.object(OaiProviderMetadataFormat, "get_all")
-    def test_get_all_contains_only_oai_provider_metadata_format(self, mock_get_all):
+    def test_get_all_contains_only_oai_provider_metadata_format(
+        self, mock_get_all
+    ):
         """test_get_all_contains_only_oai_provider_metadata_format"""
         _generic_get_all_test(
             self, mock_get_all, provider_metadata_format_api.get_all()
@@ -198,7 +215,9 @@ class TestOaiProviderMetadataFormatGetAllDefaultMetadataFormat(TestCase):
 class TestOaiProviderMetadataFormatGetAllTemplateMetadataFormat(TestCase):
     """Test Oai Provider Metadata Format Get All Template Metadata Format"""
 
-    @patch.object(OaiProviderMetadataFormat, "get_all_template_metadata_format")
+    @patch.object(
+        OaiProviderMetadataFormat, "get_all_template_metadata_format"
+    )
     def test_get_all_template_metadata_format_contains_only_oai_provider_metadata_format(
         self, mock_get_all
     ):
@@ -214,7 +233,9 @@ class TestOaiProviderMetadataFormatGetAllTemplateMetadataFormat(TestCase):
 class TestOaiProviderMetadataFormatGetAllNoTemplateMetadataFormat(TestCase):
     """Test Oai Provider Metadata Format Get All No Template Metadata Format"""
 
-    @patch.object(OaiProviderMetadataFormat, "get_all_no_template_metadata_format")
+    @patch.object(
+        OaiProviderMetadataFormat, "get_all_no_template_metadata_format"
+    )
     def test_get_all_not_template_metadata_format_contains_only_oai_provider_metadata_format(
         self, mock_get_all
     ):
@@ -235,8 +256,12 @@ class TestOaiProviderMetadataFormatGetAllByTemplates(TestCase):
         """test_get_all_by_templates_return_object"""
 
         # Arrange
-        mock_oai_provider_metadata_format1 = _create_mock_oai_provider_metadata_format()
-        mock_oai_provider_metadata_format2 = _create_mock_oai_provider_metadata_format()
+        mock_oai_provider_metadata_format1 = (
+            _create_mock_oai_provider_metadata_format()
+        )
+        mock_oai_provider_metadata_format2 = (
+            _create_mock_oai_provider_metadata_format()
+        )
 
         mock_get.return_value = [
             mock_oai_provider_metadata_format1,
@@ -282,8 +307,8 @@ class TestOaiProviderMetadataFormatGetMetadataFormatSchemaUrl(TestCase):
         """test_get_metadata_format_schema_url_returns"""
 
         # Arrange
-        mock_oai_provider_metadata_format1 = _create_mock_oai_provider_metadata_format(
-            is_template=False
+        mock_oai_provider_metadata_format1 = (
+            _create_mock_oai_provider_metadata_format(is_template=False)
         )
 
         # Act
@@ -295,7 +320,9 @@ class TestOaiProviderMetadataFormatGetMetadataFormatSchemaUrl(TestCase):
         self.assertEqual(mock_oai_provider_metadata_format1.schema, result)
 
 
-class TestOaiProviderMetadataFormatGetSimpleTemplateMetadataFormatSchemaUrl(TestCase):
+class TestOaiProviderMetadataFormatGetSimpleTemplateMetadataFormatSchemaUrl(
+    TestCase
+):
     """Test Oai Provider Metadata Format Get Simple Template Metadata Format Schema Url"""
 
     def test_get_simple_template_metadata_format_schema_url_returns(self):
@@ -316,8 +343,12 @@ class TestOaiProviderMetadataFormatGetSimpleTemplateMetadataFormatSchemaUrl(Test
 
 def _generic_get_all_test(self, mock_get_all, act_function):
     # Arrange
-    mock_oai_provider_metadata_format1 = _create_mock_oai_provider_metadata_format()
-    mock_oai_provider_metadata_format2 = _create_mock_oai_provider_metadata_format()
+    mock_oai_provider_metadata_format1 = (
+        _create_mock_oai_provider_metadata_format()
+    )
+    mock_oai_provider_metadata_format2 = (
+        _create_mock_oai_provider_metadata_format()
+    )
 
     mock_get_all.return_value = [
         mock_oai_provider_metadata_format1,
@@ -328,7 +359,9 @@ def _generic_get_all_test(self, mock_get_all, act_function):
     result = act_function
 
     # Assert
-    self.assertTrue(all(isinstance(item, OaiProviderMetadataFormat) for item in result))
+    self.assertTrue(
+        all(isinstance(item, OaiProviderMetadataFormat) for item in result)
+    )
 
 
 def _create_oai_provider_metadata_format():
@@ -360,7 +393,9 @@ def _create_mock_oai_provider_metadata_format(is_template=False):
 
 
 def _set_oai_provider_metadata_format_fields(
-    oai_provider_metadata_format, is_template=False, schema="http://test.com/test.xsd"
+    oai_provider_metadata_format,
+    is_template=False,
+    schema="http://test.com/test.xsd",
 ):
     """Set OaiProviderMetadataFormat fields.
 
