@@ -1,22 +1,35 @@
+""" Tests unit
+"""
+
+from random import randint
 from unittest.case import TestCase
+from unittest.mock import Mock, patch
 
-from bson.objectid import ObjectId
-from mock.mock import Mock, patch
-
-import core_main_app.components.template_version_manager.api as template_version_manager_api
+import core_main_app.components.template.api as template_api
 import core_oaipmh_provider_app.components.oai_provider_set.api as provider_set_api
 from core_main_app.commons import exceptions
+from core_main_app.components.template.models import Template
+from core_main_app.components.template_version_manager.models import (
+    TemplateVersionManager,
+)
 from core_main_app.utils.tests_tools.MockUser import create_mock_user
 from core_main_app.utils.tests_tools.RequestMock import create_mock_request
-from core_oaipmh_provider_app.components.oai_provider_set.models import OaiProviderSet
+from core_oaipmh_provider_app.components.oai_provider_set.models import (
+    OaiProviderSet,
+)
 
 
 class TestOaiProviderSetUpsert(TestCase):
+    """Test Oai Provider Set Upsert"""
+
     def setUp(self):
+        """setUp"""
         self.mock_oai_provider_set = _create_oai_provider_set()
 
     @patch.object(OaiProviderSet, "save")
     def test_oai_provider_set_upsert_return_object(self, mock_save):
+        """test_oai_provider_set_upsert_return_object"""
+
         # Arrange
         mock_save.return_value = self.mock_oai_provider_set
 
@@ -27,7 +40,11 @@ class TestOaiProviderSetUpsert(TestCase):
         self.assertIsInstance(result, OaiProviderSet)
 
     @patch.object(OaiProviderSet, "save")
-    def test_oai_provider_set_upsert_raises_error_if_save_failed(self, mock_save):
+    def test_oai_provider_set_upsert_raises_error_if_save_failed(
+        self, mock_save
+    ):
+        """test_oai_provider_set_upsert_raises_error_if_save_failed"""
+
         # Arrange
         mock_save.side_effect = Exception()
 
@@ -37,11 +54,15 @@ class TestOaiProviderSetUpsert(TestCase):
 
 
 class TestOaiProviderSetGetById(TestCase):
+    """Test Oai Provider Set Get By Id"""
+
     @patch.object(OaiProviderSet, "get_by_id")
     def test_get_by_id_return_object(self, mock_get_by_id):
+        """test_get_by_id_return_object"""
+
         # Arrange
         mock_oai_provider_set = _create_mock_oai_provider_set()
-        mock_oai_provider_set.id = ObjectId()
+        mock_oai_provider_set.id = randint(1, 100)
 
         mock_get_by_id.return_value = mock_oai_provider_set
 
@@ -52,9 +73,13 @@ class TestOaiProviderSetGetById(TestCase):
         self.assertIsInstance(result, OaiProviderSet)
 
     @patch.object(OaiProviderSet, "get_by_id")
-    def test_get_by_id_raises_exception_if_object_does_not_exist(self, mock_get_by_id):
+    def test_get_by_id_raises_exception_if_object_does_not_exist(
+        self, mock_get_by_id
+    ):
+        """test_get_by_id_raises_exception_if_object_does_not_exist"""
+
         # Arrange
-        mock_absent_id = ObjectId()
+        mock_absent_id = randint(1, 100)
 
         mock_get_by_id.side_effect = exceptions.DoesNotExist("Error.")
 
@@ -63,9 +88,13 @@ class TestOaiProviderSetGetById(TestCase):
             provider_set_api.get_by_id(mock_absent_id)
 
     @patch.object(OaiProviderSet, "get_by_id")
-    def test_get_by_id_raises_exception_if_internal_error(self, mock_get_by_id):
+    def test_get_by_id_raises_exception_if_internal_error(
+        self, mock_get_by_id
+    ):
+        """test_get_by_id_raises_exception_if_internal_error"""
+
         # Arrange
-        mock_absent_id = ObjectId()
+        mock_absent_id = randint(1, 100)
 
         mock_get_by_id.side_effect = exceptions.ModelError("Error.")
 
@@ -75,23 +104,33 @@ class TestOaiProviderSetGetById(TestCase):
 
 
 class TestOaiProviderSetGetBySetSpec(TestCase):
+    """Test Oai Provider Set Get By Set Spec"""
+
     @patch.object(OaiProviderSet, "get_by_set_spec")
     def test_get_by_set_spec_return_object(self, mock_get):
+        """test_get_by_set_spec_return_object"""
+
         # Arrange
         mock_oai_provider_set = _create_mock_oai_provider_set()
 
         mock_get.return_value = mock_oai_provider_set
 
         # Act
-        result = provider_set_api.get_by_set_spec(mock_oai_provider_set.set_spec)
+        result = provider_set_api.get_by_set_spec(
+            mock_oai_provider_set.set_spec
+        )
 
         # Assert
         self.assertIsInstance(result, OaiProviderSet)
 
     @patch.object(OaiProviderSet, "get_by_set_spec")
-    def test_get_by_set_spec_raises_exception_if_object_does_not_exist(self, mock_get):
+    def test_get_by_set_spec_raises_exception_if_object_does_not_exist(
+        self, mock_get
+    ):
+        """test_get_by_set_spec_raises_exception_if_object_does_not_exist"""
+
         # Arrange
-        mock_absent_set_spec = ObjectId()
+        mock_absent_set_spec = randint(1, 100)
 
         mock_get.side_effect = exceptions.DoesNotExist("Error.")
 
@@ -100,9 +139,13 @@ class TestOaiProviderSetGetBySetSpec(TestCase):
             provider_set_api.get_by_set_spec(mock_absent_set_spec)
 
     @patch.object(OaiProviderSet, "get_by_set_spec")
-    def test_get_by_set_spec_raises_exception_if_internal_error(self, mock_get):
+    def test_get_by_set_spec_raises_exception_if_internal_error(
+        self, mock_get
+    ):
+        """test_get_by_set_spec_raises_exception_if_internal_error"""
+
         # Arrange
-        mock_absent_set_spec = ObjectId()
+        mock_absent_set_spec = randint(1, 100)
 
         mock_get.side_effect = exceptions.ModelError("Error.")
 
@@ -112,29 +155,45 @@ class TestOaiProviderSetGetBySetSpec(TestCase):
 
 
 class TestOaiProviderSetGetAll(TestCase):
+    """Test Oai Provider Set Get All"""
+
     @patch.object(OaiProviderSet, "get_all")
     def test_list_contains_only_oai_provider_set(self, mock_get_all):
+        """test_list_contains_only_oai_provider_set"""
+
         # Arrange
         mock_oai_provider_set1 = _create_mock_oai_provider_set()
         mock_oai_provider_set2 = _create_mock_oai_provider_set()
 
-        mock_get_all.return_value = [mock_oai_provider_set1, mock_oai_provider_set2]
+        mock_get_all.return_value = [
+            mock_oai_provider_set1,
+            mock_oai_provider_set2,
+        ]
 
         # Act
         result = provider_set_api.get_all()
 
         # Assert
-        self.assertTrue(all(isinstance(item, OaiProviderSet) for item in result))
+        self.assertTrue(
+            all(isinstance(item, OaiProviderSet) for item in result)
+        )
 
 
 class TestOaiProviderSetGetAllByTemplatesManager(TestCase):
+    """Test Oai Provider Set Get All By Templates Manager"""
+
     @patch.object(OaiProviderSet, "get_all_by_templates_manager")
     def test_get_all_by_templates_manager_return_object(self, mock_get):
+        """test_get_all_by_templates_manager_return_object"""
+
         # Arrange
         mock_oai_provider_set1 = _create_mock_oai_provider_set()
         mock_oai_provider_set2 = _create_mock_oai_provider_set()
 
-        mock_get.return_value = [mock_oai_provider_set1, mock_oai_provider_set2]
+        mock_get.return_value = [
+            mock_oai_provider_set1,
+            mock_oai_provider_set2,
+        ]
 
         # Act
         result = provider_set_api.get_all_by_templates_manager(
@@ -142,43 +201,56 @@ class TestOaiProviderSetGetAllByTemplatesManager(TestCase):
         )
 
         # Assert
-        self.assertTrue(all(isinstance(item, OaiProviderSet) for item in result))
+        self.assertTrue(
+            all(isinstance(item, OaiProviderSet) for item in result)
+        )
 
 
 class TestOaiProviderSetGetAllByTemplates(TestCase):
-    @patch.object(template_version_manager_api, "get_all_by_version_ids")
+    """Test Oai Provider Set Get All By Templates"""
+
     @patch.object(OaiProviderSet, "get_all_by_templates_manager")
+    @patch.object(template_api, "get_by_id")
     def test_get_all_by_templates_return_object(
-        self, mock_get_all_by_templates, mock_get_all_by_version_ids
+        self,
+        mock_template_api_get_by_id,
+        mock_oai_provider_set_get_all_by_templates_manager,
     ):
+        """test_get_all_by_templates_return_object"""
+
         # Arrange
         mock_user = create_mock_user("1", is_superuser=True)
         mock_request = create_mock_request(user=mock_user)
-        template_id = ObjectId()
+        template_id = randint(1, 100)
         mock_oai_provider_set1 = _create_mock_oai_provider_set()
         mock_oai_provider_set2 = _create_mock_oai_provider_set()
 
-        mock_get_all_by_version_ids.return_value = [
-            mock_oai_provider_set1.templates_manager,
-            mock_oai_provider_set2.templates_manager,
-        ]
-        mock_get_all_by_templates.return_value = [
+        mock_oai_provider_set_get_all_by_templates_manager.return_value = [
             mock_oai_provider_set1,
             mock_oai_provider_set2,
         ]
+        mock_template_api_get_by_id.return_value = _create_mock_template()
 
         # Act
-        result = provider_set_api.get_all_by_template_ids([template_id], mock_request)
+        result = provider_set_api.get_all_by_template_ids(
+            [template_id], mock_request
+        )
 
         # Assert
-        self.assertTrue(all(isinstance(item, OaiProviderSet) for item in result))
+        self.assertTrue(
+            all(isinstance(item, OaiProviderSet) for item in result)
+        )
 
 
 class TestOaiProviderSetDelete(TestCase):
+    """Test Oai Provider Set Delete"""
+
     @patch.object(OaiProviderSet, "delete")
     def test_delete_oai_provider_set_raises_exception_if_object_does_not_exist(
         self, mock_delete
     ):
+        """test_delete_oai_provider_set_raises_exception_if_object_does_not_exist"""
+
         # Arrange
         oai_provider_set = _create_oai_provider_set()
         mock_delete.side_effect = Exception()
@@ -188,6 +260,22 @@ class TestOaiProviderSetDelete(TestCase):
             provider_set_api.delete(oai_provider_set)
 
 
+def _create_mock_template():
+    mock_template = Mock(spec=Template)
+    mock_template.version_manager = 1
+
+    return mock_template
+
+
+def _create_template_version_manager():
+    template_version_manager = TemplateVersionManager(
+        title=f"template{randint(1, 100) * randint(1, 100)}", user=1
+    )
+    template_version_manager.save()
+
+    return template_version_manager
+
+
 def _create_oai_provider_set():
     """Get an OaiProviderSet object
 
@@ -195,7 +283,6 @@ def _create_oai_provider_set():
         OaiProviderSet instance.
 
     """
-
     oai_provider_set = OaiProviderSet()
     _set_oai_provider_set_fields(oai_provider_set)
 
@@ -227,7 +314,6 @@ def _set_oai_provider_set_fields(oai_provider_set):
     """
     oai_provider_set.set_spec = "oai_test"
     oai_provider_set.set_name = "test"
-    oai_provider_set.templates_manager = [ObjectId(), ObjectId()]
     oai_provider_set.description = "OaiSet description"
 
     return oai_provider_set
