@@ -2,11 +2,10 @@
 """
 
 from unittest.case import TestCase
-
 from unittest.mock import Mock, patch
 
-from core_main_app.commons import exceptions
 import core_oaipmh_provider_app.components.oai_settings.api as settings_api
+from core_main_app.commons import exceptions
 from core_oaipmh_provider_app.components.oai_settings.models import OaiSettings
 
 
@@ -55,7 +54,9 @@ class TestOaiSettingsUpsert(TestCase):
     """Test Oai Settings Upsert"""
 
     @patch.object(OaiSettings, "save")
-    def test_upsert_oai_settings_raises_exception_if_save_failed(self, mock_save):
+    def test_upsert_oai_settings_raises_exception_if_save_failed(
+        self, mock_save
+    ):
         """test_upsert_oai_settings_raises_exception_if_save_failed"""
 
         # Arrange
