@@ -1,16 +1,18 @@
 """ Unit Test Rest OaiProviderMetadataFormat
 """
+from random import randint
+from unittest.mock import patch, Mock
 
 import requests
-from bson.objectid import ObjectId
-from django.test.testcases import SimpleTestCase
-from mock.mock import patch, Mock
+from django.test.testcases import SimpleTestCase, TestCase
 from rest_framework import status
 
 from core_main_app.commons import exceptions
 from core_main_app.components.template import api as template_api
 from core_main_app.components.template.models import Template
-from core_main_app.components.xsl_transformation.models import XslTransformation
+from core_main_app.components.xsl_transformation.models import (
+    XslTransformation,
+)
 from core_main_app.utils.tests_tools.MockUser import create_mock_user
 from core_main_app.utils.tests_tools.RequestMock import RequestMock
 from core_oaipmh_provider_app.components.oai_provider_metadata_format import (
@@ -19,18 +21,26 @@ from core_oaipmh_provider_app.components.oai_provider_metadata_format import (
 from core_oaipmh_provider_app.components.oai_provider_metadata_format.models import (
     OaiProviderMetadataFormat,
 )
-from core_oaipmh_provider_app.components.oai_xsl_template.models import OaiXslTemplate
+from core_oaipmh_provider_app.components.oai_xsl_template.models import (
+    OaiXslTemplate,
+)
 from core_oaipmh_provider_app.rest.oai_provider_metadata_format import (
     views as rest_oai_provider_metadata_format,
 )
 
 
 class TestSelectMetadataFormat(SimpleTestCase):
+    """Test Select Metadata Format"""
+
     def setUp(self):
-        super(TestSelectMetadataFormat, self).setUp()
-        self.param = {"metadata_format_id": str(ObjectId())}
+        """setUp"""
+
+        super().setUp()
+        self.param = {"metadata_format_id": randint(1, 100)}
 
     def test_select_metadata_format_unauthorized(self):
+        """test_select_metadata_format_unauthorized"""
+
         # Arrange
         user = create_mock_user("1", is_staff=False)
 
@@ -46,6 +56,8 @@ class TestSelectMetadataFormat(SimpleTestCase):
 
     @patch.object(OaiProviderMetadataFormat, "get_by_id")
     def test_select_metadata_format_not_found(self, mock_get_by_id):
+        """test_select_metadata_format_not_found"""
+
         # Arrange
         mock_get_by_id.side_effect = exceptions.DoesNotExist("Error")
 
@@ -61,11 +73,17 @@ class TestSelectMetadataFormat(SimpleTestCase):
 
 
 class TestSelectAllMetadataFormats(SimpleTestCase):
+    """Test Select All Metadata Formats"""
+
     def setUp(self):
-        super(TestSelectAllMetadataFormats, self).setUp()
+        """setUp"""
+
+        super().setUp()
         self.data = None
 
     def test_select_all_metadata_formats_unauthorized(self):
+        """test_select_all_metadata_formats_unauthorized"""
+
         # Arrange
         user = create_mock_user("1", is_staff=False)
 
@@ -81,8 +99,12 @@ class TestSelectAllMetadataFormats(SimpleTestCase):
 
 
 class TestAddMetadataFormat(SimpleTestCase):
+    """Test Add Metadata Format"""
+
     def setUp(self):
-        super(TestAddMetadataFormat, self).setUp()
+        """setUp"""
+
+        super().setUp()
         self.data = {
             "metadata_prefix": "oai_test",
             "schema_url": "http://www.dummy.org",
@@ -90,6 +112,8 @@ class TestAddMetadataFormat(SimpleTestCase):
         self.bad_data = {}
 
     def test_add_metadata_format_unauthorized(self):
+        """test_add_metadata_format_unauthorized"""
+
         # Arrange
         user = create_mock_user("1", is_staff=False)
 
@@ -104,6 +128,8 @@ class TestAddMetadataFormat(SimpleTestCase):
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
     def test_add_metadata_format_serializer_invalid(self):
+        """test_add_metadata_format_serializer_invalid"""
+
         # Act
         response = RequestMock.do_request_post(
             rest_oai_provider_metadata_format.MetadataFormatsList.as_view(),
@@ -115,7 +141,11 @@ class TestAddMetadataFormat(SimpleTestCase):
         self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
 
     @patch.object(requests, "get")
-    def test_add_metadata_format_raises_exception_if_bad_schema_url(self, mock_get):
+    def test_add_metadata_format_raises_exception_if_bad_schema_url(
+        self, mock_get
+    ):
+        """test_add_metadata_format_raises_exception_if_bad_schema_url"""
+
         # Arrange
         text = "<test>Hello</test>"
         mock_get.return_value.status_code = status.HTTP_404_NOT_FOUND
@@ -133,6 +163,8 @@ class TestAddMetadataFormat(SimpleTestCase):
 
     @patch.object(requests, "get")
     def test_add_metadata_format_raises_exception_if_bad_xml(self, mock_get):
+        """test_add_metadata_format_raises_exception_if_bad_xml"""
+
         # Arrange
         text = "<test>Hello/test>"
         mock_get.return_value.status_code = status.HTTP_200_OK
@@ -150,12 +182,21 @@ class TestAddMetadataFormat(SimpleTestCase):
 
 
 class TestAddTemplateMetadataFormat(SimpleTestCase):
+    """Test Add Template Metadata Format"""
+
     def setUp(self):
-        super(TestAddTemplateMetadataFormat, self).setUp()
-        self.data = {"metadata_prefix": "oai_test", "template_id": str(ObjectId())}
+        """setUp"""
+
+        super().setUp()
+        self.data = {
+            "metadata_prefix": "oai_test",
+            "template_id": randint(1, 100),
+        }
         self.bad_data = {}
 
     def test_add_template_metadata_format_unauthorized(self):
+        """test_add_template_metadata_format_unauthorized"""
+
         # Arrange
         user = create_mock_user("1", is_staff=False)
 
@@ -170,6 +211,8 @@ class TestAddTemplateMetadataFormat(SimpleTestCase):
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
     def test_add_template_metadata_format_serializer_invalid(self):
+        """test_add_template_metadata_format_serializer_invalid"""
+
         # Act
         response = RequestMock.do_request_post(
             rest_oai_provider_metadata_format.TemplateAsMetadataFormat.as_view(),
@@ -180,10 +223,12 @@ class TestAddTemplateMetadataFormat(SimpleTestCase):
         # Assert
         self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
 
-    @patch.object(template_api, "get")
+    @patch.object(template_api, "get_by_id")
     def test_add_template_metadata_format_raises_exception_if_template_does_not_exist(
         self, mock_get_by_id
     ):
+        """test_add_template_metadata_format_raises_exception_if_template_does_not_exist"""
+
         # Arrange
         mock_get_by_id.side_effect = exceptions.DoesNotExist("Error")
 
@@ -199,13 +244,19 @@ class TestAddTemplateMetadataFormat(SimpleTestCase):
 
 
 class TestUpdateMetadataFormat(SimpleTestCase):
+    """Test Update Metadata Format"""
+
     def setUp(self):
-        super(TestUpdateMetadataFormat, self).setUp()
+        """setUp"""
+
+        super().setUp()
         self.data = {"metadata_prefix": "oai_update"}
-        self.param = {"metadata_format_id": str(ObjectId())}
+        self.param = {"metadata_format_id": randint(1, 100)}
         self.bad_data = {}
 
     def test_update_metadata_format_unauthorized(self):
+        """test_update_metadata_format_unauthorized"""
+
         # Act
         response = RequestMock.do_request_patch(
             rest_oai_provider_metadata_format.MetadataFormatDetail.as_view(),
@@ -218,9 +269,15 @@ class TestUpdateMetadataFormat(SimpleTestCase):
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
     @patch.object(OaiProviderMetadataFormat, "get_by_id")
-    def test_update_metadata_format_serializer_invalid(self, mock_metadata_format):
+    def test_update_metadata_format_serializer_invalid(
+        self, mock_metadata_format
+    ):
+        """test_update_metadata_format_serializer_invalid"""
+
         # Arrange
-        mock_metadata_format.return_value = Mock(spec=OaiProviderMetadataFormat())
+        mock_metadata_format.return_value = Mock(
+            spec=OaiProviderMetadataFormat()
+        )
         # Act
         response = RequestMock.do_request_patch(
             rest_oai_provider_metadata_format.MetadataFormatDetail.as_view(),
@@ -234,6 +291,8 @@ class TestUpdateMetadataFormat(SimpleTestCase):
 
     @patch.object(OaiProviderMetadataFormat, "get_by_id")
     def test_update_metadata_format_not_found(self, mock_get_by_id):
+        """test_update_metadata_format_not_found"""
+
         # Arrange
         mock_get_by_id.side_effect = exceptions.DoesNotExist("Error")
 
@@ -249,17 +308,23 @@ class TestUpdateMetadataFormat(SimpleTestCase):
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
 
-class TestTemplateToMetadataFormatMappingXslt(SimpleTestCase):
+class TestTemplateToMetadataFormatMappingXslt(TestCase):
+    """Test Template To Metadata Format Mapping Xslt"""
+
     def setUp(self):
-        super(TestTemplateToMetadataFormatMappingXslt, self).setUp()
+        """setUp"""
+
+        super().setUp()
         self.data = {
-            "template": str(ObjectId()),
-            "oai_metadata_format": str(ObjectId()),
-            "xslt": str(ObjectId()),
+            "template": randint(1, 100),
+            "oai_metadata_format": randint(1, 100),
+            "xslt": randint(1, 100),
         }
         self.bad_data = {}
 
     def test_template_to_metadata_format_mapping_xslt_unauthorized(self):
+        """test_template_to_metadata_format_mapping_xslt_unauthorized"""
+
         # Act
         response = RequestMock.do_request_post(
             rest_oai_provider_metadata_format.TemplateMetadataFormatXSLT.as_view(),
@@ -271,6 +336,8 @@ class TestTemplateToMetadataFormatMappingXslt(SimpleTestCase):
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
     def test_template_to_metadata_format_mapping_xslt_serializer_invalid(self):
+        """test_template_to_metadata_format_mapping_xslt_serializer_invalid"""
+
         # Act
         response = RequestMock.do_request_post(
             rest_oai_provider_metadata_format.TemplateMetadataFormatXSLT.as_view(),
@@ -285,6 +352,8 @@ class TestTemplateToMetadataFormatMappingXslt(SimpleTestCase):
     def test_template_to_metadata_format_mapping_xslt_template_not_found(
         self, mock_get_by_id
     ):
+        """test_template_to_metadata_format_mapping_xslt_template_not_found"""
+
         # Arrange
         mock_get_by_id.side_effect = exceptions.DoesNotExist("Error")
 
@@ -303,6 +372,8 @@ class TestTemplateToMetadataFormatMappingXslt(SimpleTestCase):
     def test_template_to_metadata_format_mapping_xslt_oai_xslt_template_not_found(
         self, mock_get_template, mock_get_by_id
     ):
+        """test_template_to_metadata_format_mapping_xslt_oai_xslt_template_not_found"""
+
         # Arrange
         mock_get_template.return_value = Mock(spec=Template)
         mock_get_by_id.side_effect = exceptions.DoesNotExist("Error")
@@ -323,6 +394,8 @@ class TestTemplateToMetadataFormatMappingXslt(SimpleTestCase):
     def test_template_to_metadata_format_mapping_xslt_metadata_format_not_found(
         self, mock_get_xslt, mock_get_template, mock_get_by_id
     ):
+        """test_template_to_metadata_format_mapping_xslt_metadata_format_not_found"""
+
         # Arrange
         mock_get_xslt.return_value = Mock(spec=XslTransformation)
         mock_get_template.return_value = Mock(spec=Template)
@@ -344,6 +417,8 @@ class TestTemplateToMetadataFormatMappingXslt(SimpleTestCase):
     def test_template_to_metadata_format_mapping_xslt_impossible_temp_meta_form(
         self, mock_get_xslt, mock_get_template, mock_get_meta_form
     ):
+        """test_template_to_metadata_format_mapping_xslt_impossible_temp_meta_form"""
+
         # Arrange
         mock_get_xslt.return_value = Mock(spec=XslTransformation)
         mock_get_template.return_value = Mock(spec=Template)
@@ -368,15 +443,21 @@ class TestTemplateToMetadataFormatMappingXslt(SimpleTestCase):
 
 
 class TestTemplateToMetadataFormatUnMappingXslt(SimpleTestCase):
+    """Test Template To Metadata Format UnMapping Xslt"""
+
     def setUp(self):
-        super(TestTemplateToMetadataFormatUnMappingXslt, self).setUp()
+        """setUp"""
+
+        super().setUp()
         self.data = {
-            "template_id": str(ObjectId()),
-            "metadata_format_id": str(ObjectId()),
+            "template_id": randint(1, 100),
+            "metadata_format_id": randint(1, 100),
         }
         self.bad_data = {}
 
     def test_template_to_metadata_format_unmapping_xslt_unauthorized(self):
+        """test_template_to_metadata_format_unmapping_xslt_unauthorized"""
+
         # Act
         response = RequestMock.do_request_delete(
             rest_oai_provider_metadata_format.TemplateMetadataFormatXSLT.as_view(),
@@ -387,7 +468,11 @@ class TestTemplateToMetadataFormatUnMappingXslt(SimpleTestCase):
         # Assert
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
-    def test_template_to_metadata_format_unmapping_xslt_serializer_invalid(self):
+    def test_template_to_metadata_format_unmapping_xslt_serializer_invalid(
+        self,
+    ):
+        """test_template_to_metadata_format_unmapping_xslt_serializer_invalid"""
+
         # Act
         response = RequestMock.do_request_delete(
             rest_oai_provider_metadata_format.TemplateMetadataFormatXSLT.as_view(),
@@ -399,7 +484,11 @@ class TestTemplateToMetadataFormatUnMappingXslt(SimpleTestCase):
         self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
 
     @patch.object(OaiXslTemplate, "get_by_template_id_and_metadata_format_id")
-    def test_template_to_metadata_format_unmapping_xslt_not_found(self, mock_get_by_id):
+    def test_template_to_metadata_format_unmapping_xslt_not_found(
+        self, mock_get_by_id
+    ):
+        """test_template_to_metadata_format_unmapping_xslt_not_found"""
+
         # Arrange
         mock_get_by_id.side_effect = exceptions.DoesNotExist("Error")
 
@@ -415,11 +504,17 @@ class TestTemplateToMetadataFormatUnMappingXslt(SimpleTestCase):
 
 
 class TestDeleteMetadataFormat(SimpleTestCase):
+    """Test Delete Metadata Format"""
+
     def setUp(self):
-        super(TestDeleteMetadataFormat, self).setUp()
-        self.param = {"metadata_format_id": str(ObjectId())}
+        """setUp"""
+
+        super().setUp()
+        self.param = {"metadata_format_id": randint(1, 100)}
 
     def test_delete_metadata_format_unauthorized(self):
+        """test_delete_metadata_format_unauthorized"""
+
         # Act
         response = RequestMock.do_request_delete(
             rest_oai_provider_metadata_format.MetadataFormatDetail.as_view(),
@@ -432,6 +527,8 @@ class TestDeleteMetadataFormat(SimpleTestCase):
 
     @patch.object(oai_provider_metadata_format_api, "get_by_id")
     def test_delete_metadata_format_not_found(self, mock_get_by_id):
+        """test_delete_metadata_format_not_found"""
+
         # Arrange
         mock_get_by_id.side_effect = exceptions.DoesNotExist("Error")
 
