@@ -1,6 +1,6 @@
 """ Int Test Rest OaiProviderSet
 """
-from bson.objectid import ObjectId
+
 from rest_framework import status
 
 from core_main_app.utils.integration_tests.integration_base_test_case import (
@@ -8,7 +8,9 @@ from core_main_app.utils.integration_tests.integration_base_test_case import (
 )
 from core_main_app.utils.tests_tools.MockUser import create_mock_user
 from core_main_app.utils.tests_tools.RequestMock import RequestMock
-from core_oaipmh_provider_app.components.oai_provider_set.models import OaiProviderSet
+from core_oaipmh_provider_app.components.oai_provider_set.models import (
+    OaiProviderSet,
+)
 from core_oaipmh_provider_app.rest.oai_provider_set import (
     views as rest_oai_provider_set,
 )
@@ -16,19 +18,27 @@ from tests.utils.fixtures.fixtures import OaiPmhFixtures, OaiPmhMock
 
 
 class TestSelectSet(MongoIntegrationBaseTestCase):
+    """Test Select Set"""
+
     fixture = OaiPmhFixtures()
 
     def setUp(self):
-        super(TestSelectSet, self).setUp()
+        """setUp"""
+
+        super().setUp()
         self.param = {"set_id": str(OaiPmhMock().mock_oai_first_set().id)}
 
     def test_select_set_returns(self):
+        """test_select_set_returns"""
+
         # Arrange
         user = create_mock_user("1", is_staff=True)
 
         # Act
         response = RequestMock.do_request_get(
-            rest_oai_provider_set.SetDetail.as_view(), user=user, param=self.param
+            rest_oai_provider_set.SetDetail.as_view(),
+            user=user,
+            param=self.param,
         )
 
         # Assert
@@ -36,13 +46,19 @@ class TestSelectSet(MongoIntegrationBaseTestCase):
 
 
 class TestSelectAllSets(MongoIntegrationBaseTestCase):
+    """Test Select All Sets"""
+
     fixture = OaiPmhFixtures()
 
     def setUp(self):
-        super(TestSelectAllSets, self).setUp()
+        """setUp"""
+
+        super().setUp()
         self.data = None
 
     def test_select_all_sets(self):
+        """test_select_all_sets"""
+
         # Arrange
         user = create_mock_user("1", is_staff=True)
 
@@ -56,19 +72,25 @@ class TestSelectAllSets(MongoIntegrationBaseTestCase):
 
 
 class TestAddSet(MongoIntegrationBaseTestCase):
+    """Test Add Set"""
+
     fixture = OaiPmhFixtures()
 
     def setUp(self):
-        super(TestAddSet, self).setUp()
+        """setUp"""
+
+        super().setUp()
         self.data = {
             "set_spec": "oai_dummy",
             "set_name": "dummy set",
-            "templates_manager": [str(ObjectId()), str(ObjectId())],
+            "templates_manager": [],
             "description": "The description",
         }
         self.nb_sets = len(OaiProviderSet.objects.all())
 
     def test_add_set(self):
+        """test_add_set"""
+
         # Arrange
         user = create_mock_user("1", is_staff=True)
 
@@ -83,14 +105,20 @@ class TestAddSet(MongoIntegrationBaseTestCase):
 
 
 class TestDeleteSet(MongoIntegrationBaseTestCase):
+    """Test Delete Set"""
+
     fixture = OaiPmhFixtures()
 
     def setUp(self):
-        super(TestDeleteSet, self).setUp()
+        """setUp"""
+
+        super().setUp()
         self.param = {"set_id": str(OaiPmhMock().mock_oai_first_set().id)}
         self.nb_sets = len(OaiProviderSet.objects.all())
 
     def test_delete_set(self):
+        """test_delete_set"""
+
         # Arrange
         user = create_mock_user("1", is_staff=True)
 
@@ -105,10 +133,14 @@ class TestDeleteSet(MongoIntegrationBaseTestCase):
 
 
 class TestUpdateSet(MongoIntegrationBaseTestCase):
+    """Test Update Set"""
+
     fixture = OaiPmhFixtures()
 
     def setUp(self):
-        super(TestUpdateSet, self).setUp()
+        """setUp"""
+
+        super().setUp()
         self.first_set = OaiPmhMock.mock_oai_first_set()
         self.new_set_spec = "{0}_new".format(self.first_set.set_spec)
         self.new_set_name = "{0}_new".format(self.first_set.set_name)
@@ -119,10 +151,12 @@ class TestUpdateSet(MongoIntegrationBaseTestCase):
             "set_spec": self.new_set_spec,
             "set_name": self.new_set_name,
             "description": self.new_description,
-            "templates_manager": [str(self.new_template_version.id)],
+            "templates_manager": [self.new_template_version.pk],
         }
 
     def test_update_set(self):
+        """test_update_set"""
+
         # Arrange
         user = create_mock_user("1", is_staff=True)
 
@@ -137,16 +171,22 @@ class TestUpdateSet(MongoIntegrationBaseTestCase):
         # Assert
         self.assertEqual(response.status_code, status.HTTP_200_OK)
         self.assertEqual(
-            OaiProviderSet.objects.get(pk=self.first_set.id).set_spec, self.new_set_spec
+            OaiProviderSet.objects.get(pk=self.first_set.id).set_spec,
+            self.new_set_spec,
         )
         self.assertEqual(
-            OaiProviderSet.objects.get(pk=self.first_set.id).set_name, self.new_set_name
+            OaiProviderSet.objects.get(pk=self.first_set.id).set_name,
+            self.new_set_name,
         )
         self.assertEqual(
             OaiProviderSet.objects.get(pk=self.first_set.id).description,
             self.new_description,
         )
         self.assertEqual(
-            OaiProviderSet.objects.get(pk=self.first_set.id).templates_manager,
+            list(
+                OaiProviderSet.objects.get(
+                    pk=self.first_set.id
+                ).templates_manager.all()
+            ),
             [self.new_template_version],
         )
