@@ -1,19 +1,27 @@
 """ Authentication tests for OAIProviderSet REST API
 """
+from unittest.mock import patch, Mock
+
 from django.test import SimpleTestCase
-from mock import Mock
-from mock.mock import patch
 from rest_framework import status
 
 from core_main_app.utils.tests_tools.MockUser import create_mock_user
 from core_main_app.utils.tests_tools.RequestMock import RequestMock
-from core_oaipmh_provider_app.components.oai_provider_set.models import OaiProviderSet
-from core_oaipmh_provider_app.rest.oai_provider_set import views as oai_provider_views
+from core_oaipmh_provider_app.components.oai_provider_set.models import (
+    OaiProviderSet,
+)
+from core_oaipmh_provider_app.rest.oai_provider_set import (
+    views as oai_provider_views,
+)
 from core_oaipmh_provider_app.rest.serializers import OaiProviderSetSerializer
 
 
 class SetListGetPermission(SimpleTestCase):
+    """Set List Get Permission"""
+
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403"""
+
         response = RequestMock.do_request_get(
             oai_provider_views.SetsList.as_view(), None
         )
@@ -21,6 +29,8 @@ class SetListGetPermission(SimpleTestCase):
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
     def test_authenticated_returns_http_403(self):
+        """test_authenticated_returns_http_403"""
+
         mock_user = create_mock_user("1")
 
         response = RequestMock.do_request_get(
@@ -31,6 +41,8 @@ class SetListGetPermission(SimpleTestCase):
 
     @patch.object(OaiProviderSet, "get_all")
     def test_staff_returns_http_200(self, oai_provider_set_get_all):
+        """test_staff_returns_http_200"""
+
         oai_provider_set_get_all.return_value = {}
         mock_user = create_mock_user("1", is_staff=True)
 
@@ -42,7 +54,11 @@ class SetListGetPermission(SimpleTestCase):
 
 
 class SetListPostPermission(SimpleTestCase):
+    """Set List Post Permission"""
+
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403"""
+
         response = RequestMock.do_request_post(
             oai_provider_views.SetsList.as_view(), None
         )
@@ -50,6 +66,8 @@ class SetListPostPermission(SimpleTestCase):
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
     def test_authenticated_returns_http_403(self):
+        """test_authenticated_returns_http_403"""
+
         mock_user = create_mock_user("1")
 
         response = RequestMock.do_request_post(
@@ -67,6 +85,8 @@ class SetListPostPermission(SimpleTestCase):
         oai_provider_set_serializer_save,
         oai_provider_set_serializer_is_valid,
     ):
+        """test_staff_returns_http_201"""
+
         oai_provider_set_serializer_data.return_value = True
         oai_provider_set_serializer_save.return_value = None
         oai_provider_set_serializer_is_valid.return_value = {}
@@ -80,17 +100,27 @@ class SetListPostPermission(SimpleTestCase):
 
 
 class SetDetailGetPermission(SimpleTestCase):
+    """Set Detail Get Permission"""
+
     def setUp(self):
+        """setUp"""
+
         self.fake_id = "507f1f77bcf86cd799439011"
 
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403"""
+
         response = RequestMock.do_request_get(
-            oai_provider_views.SetDetail.as_view(), None, param={"set_id": self.fake_id}
+            oai_provider_views.SetDetail.as_view(),
+            None,
+            param={"set_id": self.fake_id},
         )
 
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
     def test_authenticated_returns_http_403(self):
+        """test_authenticated_returns_http_403"""
+
         mock_user = create_mock_user("1")
 
         response = RequestMock.do_request_get(
@@ -106,6 +136,8 @@ class SetDetailGetPermission(SimpleTestCase):
     def test_staff_returns_http_200(
         self, oai_provider_set_serializer_data, oai_provider_set_get_by_id
     ):
+        """test_staff_returns_http_200"""
+
         oai_provider_set_serializer_data.return_value = True
         oai_provider_set_get_by_id.return_value = {}
         mock_user = create_mock_user("1", is_staff=True)
@@ -120,17 +152,27 @@ class SetDetailGetPermission(SimpleTestCase):
 
 
 class SetDetailDeletePermission(SimpleTestCase):
+    """Set Detail Delete Permission"""
+
     def setUp(self):
+        """setUp"""
+
         self.fake_id = "507f1f77bcf86cd799439011"
 
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403"""
+
         response = RequestMock.do_request_delete(
-            oai_provider_views.SetDetail.as_view(), None, param={"set_id": self.fake_id}
+            oai_provider_views.SetDetail.as_view(),
+            None,
+            param={"set_id": self.fake_id},
         )
 
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
     def test_authenticated_returns_http_403(self):
+        """test_authenticated_returns_http_403"""
+
         mock_user = create_mock_user("1")
 
         response = RequestMock.do_request_delete(
@@ -146,6 +188,8 @@ class SetDetailDeletePermission(SimpleTestCase):
     def test_staff_returns_http_204(
         self, oai_provider_set_delete, oai_provider_set_get_by_id
     ):
+        """test_staff_returns_http_204"""
+
         oai_provider_set_get_by_id.return_value = _create_mock_provider()
         oai_provider_set_delete.return_value = {}
         mock_user = create_mock_user("1", is_staff=True)
@@ -160,17 +204,27 @@ class SetDetailDeletePermission(SimpleTestCase):
 
 
 class SetDetailPatchPermission(SimpleTestCase):
+    """Set Detail Patch Permission"""
+
     def setUp(self):
+        """setUp"""
+
         self.fake_id = "507f1f77bcf86cd799439011"
 
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403"""
+
         response = RequestMock.do_request_patch(
-            oai_provider_views.SetDetail.as_view(), None, param={"set_id": self.fake_id}
+            oai_provider_views.SetDetail.as_view(),
+            None,
+            param={"set_id": self.fake_id},
         )
 
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
     def test_authenticated_returns_http_403(self):
+        """test_authenticated_returns_http_403"""
+
         mock_user = create_mock_user("1")
 
         response = RequestMock.do_request_patch(
@@ -192,6 +246,8 @@ class SetDetailPatchPermission(SimpleTestCase):
         oai_provider_set_serializer_is_valid,
         oai_provider_set_get_by_id,
     ):
+        """test_staff_returns_http_200"""
+
         oai_provider_set_get_by_id.return_value = _create_mock_provider()
         oai_provider_set_serializer_data.return_value = True
         oai_provider_set_serializer_save.return_value = None
