@@ -1,7 +1,8 @@
 """ Authentication tests for OAI Settings REST API
 """
-from django.test import SimpleTestCase
 from unittest.mock import patch, Mock
+
+from django.test import SimpleTestCase
 from rest_framework import status
 from rest_framework.status import HTTP_200_OK
 
@@ -18,7 +19,9 @@ class SettingsGetPermission(SimpleTestCase):
     def test_anonymous_returns_http_403(self):
         """test_anonymous_returns_http_403"""
 
-        response = RequestMock.do_request_get(settings_views.Settings.as_view(), None)
+        response = RequestMock.do_request_get(
+            settings_views.Settings.as_view(), None
+        )
 
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
@@ -57,7 +60,9 @@ class SettingsPatchPermission(SimpleTestCase):
     def test_anonymous_returns_http_403(self):
         """test_anonymous_returns_http_403"""
 
-        response = RequestMock.do_request_patch(settings_views.Settings.as_view(), None)
+        response = RequestMock.do_request_patch(
+            settings_views.Settings.as_view(), None
+        )
 
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
@@ -104,7 +109,9 @@ class CheckGetPermission(SimpleTestCase):
     def test_anonymous_returns_http_403(self):
         """test_anonymous_returns_http_403"""
 
-        response = RequestMock.do_request_get(settings_views.Check.as_view(), None)
+        response = RequestMock.do_request_get(
+            settings_views.Check.as_view(), None
+        )
 
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
@@ -113,7 +120,9 @@ class CheckGetPermission(SimpleTestCase):
 
         mock_user = create_mock_user("1")
 
-        response = RequestMock.do_request_get(settings_views.Check.as_view(), mock_user)
+        response = RequestMock.do_request_get(
+            settings_views.Check.as_view(), mock_user
+        )
 
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
@@ -126,7 +135,9 @@ class CheckGetPermission(SimpleTestCase):
         )
         mock_user = create_mock_user("1", is_staff=True)
 
-        response = RequestMock.do_request_get(settings_views.Check.as_view(), mock_user)
+        response = RequestMock.do_request_get(
+            settings_views.Check.as_view(), mock_user
+        )
 
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
