@@ -1,6 +1,7 @@
 """ Integrations tests for user views
 """
 from unittest.mock import patch, PropertyMock
+
 from rest_framework import status
 
 from core_main_app.components.data.models import Data
@@ -16,8 +17,6 @@ from core_oaipmh_provider_app.views.user.views import OAIProviderView
 from tests.utils.fixtures.fixtures import OaiPmhFixtures
 from tests.utils.test_oai_pmh_suite import TestOaiPmhSuite
 
-fixture_data = OaiPmhFixtures()
-
 
 class TestVerbs(TestOaiPmhSuite, MongoIntegrationBaseTestCase):
     """MongoIntegrationBaseTestCase"""
@@ -75,7 +74,9 @@ class TestVerbs(TestOaiPmhSuite, MongoIntegrationBaseTestCase):
         self.assertEqual(response.status_code, status.HTTP_200_OK)
         self.check_tag_exist(response.rendered_content, "ListIdentifiers")
         self.check_tag_count(
-            response.rendered_content, "identifier", self.fixture.nb_public_data
+            response.rendered_content,
+            "identifier",
+            self.fixture.nb_oai_data,
         )
 
     @patch.object(Data, "xml_content", new_callable=PropertyMock)
@@ -95,11 +96,15 @@ class TestVerbs(TestOaiPmhSuite, MongoIntegrationBaseTestCase):
         self.assertEqual(response.status_code, status.HTTP_200_OK)
         self.check_tag_exist(response.rendered_content, "ListRecords")
         self.check_tag_count(
-            response.rendered_content, "record", self.fixture.nb_public_data
+            response.rendered_content, "record", self.fixture.nb_oai_data
         )
 
-    @patch.object(oai_provider_metadata_format_api, "get_metadata_format_schema_url")
-    def test_get_list_metadata_formats(self, mock_get_metadata_format_schema_url):
+    @patch.object(
+        oai_provider_metadata_format_api, "get_metadata_format_schema_url"
+    )
+    def test_get_list_metadata_formats(
+        self, mock_get_metadata_format_schema_url
+    ):
         """test_get_list_metadata_formats"""
 
         # Arrange
@@ -120,7 +125,9 @@ class TestVerbs(TestOaiPmhSuite, MongoIntegrationBaseTestCase):
             len(self.fixture.oai_metadata_formats),
         )
 
-    @patch.object(oai_provider_metadata_format_api, "get_metadata_format_schema_url")
+    @patch.object(
+        oai_provider_metadata_format_api, "get_metadata_format_schema_url"
+    )
     def test_get_list_metadata_formats_with_identifier(
         self, mock_get_metadata_format_schema_url
     ):
